pub struct CreatePullRequestArgs {
pub assignees: Option<Vec<String>>,
pub target_branch: Option<String>,
pub body: Option<String>,
pub source_branch: Option<String>,
pub labels: Option<Vec<String>>,
pub title: Option<String>,
pub milestone: Option<String>,
pub interactive: bool,
}Expand description
Create a pull request
Fields
assignees: Option<Vec<String>>Comma-delimited list of assignee names
target_branch: Option<String>Target branch for the pull request
body: Option<String>Main description of the pull request
source_branch: Option<String>Source branch of the pull request
labels: Option<Vec<String>>Comma-delimited list of labels
title: Option<String>Title or summary
milestone: Option<String>Name of the milestone the pull request is related to
interactive: boolInteractive mode which guides the user through optional argument options
Implementations
Sourceimpl CreatePullRequestArgs
impl CreatePullRequestArgs
pub async fn run(self, general_args: GeneralArgs) -> Result<()>