pub struct BergCommand {
pub sub: BergActions,
pub output_mode: OutputMode,
pub non_interactive: bool,
pub max_width: Option<i32>,
pub owner_repo: Option<OwnerRepo>,
}Fields
sub: BergActionsoutput_mode: OutputModeHow to display the responses of the forgejo instance if there are any
non_interactive: boolWhether or not to disable all interactive features. In this case arguments have to be provided in the console!
Still WIP
max_width: Option<i32>Maximum with of the stdout output,
-
negative numbers indicate using ‘infinite’ width per line
-
zero indicates using the terminals width
-
positive numbers are interpreted as max width. You may specify widths that can lead to weird linebreaks. This is a feature for tools which process stdout output line by line. You may also just negative widths in this case. We discourage use of widths <= 25
Falls back to max_width value in config or defaults to 80 otherwise.
owner_repo: Option<OwnerRepo>The OWNER/REPO tuple if you want to target a repository other than the one in $PWD
Implementations