Module ui

Module ui 

Functions

confirm_with_prompt
Common confimation prompt (y/n) which maps
fuzzy_select_with_key
Basically the same as fuzzy_select_with_key_with_default without a default value
fuzzy_select_with_key_with_default
Given a list of items, this function allows the user to interactively select a exactly one item of the given list.
multi_fuzzy_select_with_key
Given a list of items, this function allows the user to interactively select a subset of the given list.
select_state
Select a forgejo_api::structs::StateType and serialize it the right way into a String … It has to be lowercase, otherwise the API will not detect it