BergConfig

Struct BergConfig 

pub struct BergConfig {
    pub base_url: String,
    pub enable_https: bool,
    pub fancy_tables: bool,
    pub no_color: bool,
    pub editor: String,
    pub max_width: i32,
}
Parsed configuration of the berg client

Fields

base_url: String

base url for the forgejo instance that were going to talk to

enable_https: bool

whether or not to use HTTPS

  • true -> HTTPS
  • false -> HTTP

Note that in some places (e.g. cloning a repo) other protocols like SSH are utilized, but generally we stick with good old HTTP(S) for most of the work

fancy_tables: bool

the output of some actions is displayed in a table format. This can optionally be disabled to make the output more machine readable

no_color: bool

the output of some actions is displayed with extra colors in the terminal. This can optionally be disabled in case of e.g. color blindness

WIP this does nothing yet since we don’t have colors anyways yet

editor: String

The editor to be used when doing operations such as writing a comment

max_width: i32

Maximum with of the stdout output,

  • negative numbers indicate using ‘infinite’ width per line
  • zero indicates using the terminals width
  • positive numbers are interpreted as max width. You may specify widths that can lead to weird linebreaks. This is a feature for tools which process stdout output line by line. You may also just negative widths in this case.

Falls back to max_width value in config or defaults to 80 otherwise.

Implementations

Source

impl BergConfig

pub fn new() -> Result<Self>

tries to read berg config from a known set of locations:

The following list is ordered with descending priority

  • environment variables of the form “BERG_CONFIG_FIELD_NAME”
  • current directory + “berg.toml”
  • data dir + “.berg-cli/berg.toml”“

Note that config options are overridden with these priorities. This implies that if both global and local configs exist, all existing options from the local config override the global configs options. On the other hand, if some options are not overridden, then the global ones are used in this scenario.

pub fn raw() -> Result<Config>

Source

impl BergConfig

pub fn url(&self) -> Result<Url>

pub fn make_table(&self) -> TableWrapper